# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['OriginPoolArgs', 'OriginPool']

@pulumi.input_type
class OriginPoolArgs:
    def __init__(__self__, *,
                 origin_pool_name: pulumi.Input[builtins.str],
                 site_id: pulumi.Input[builtins.int],
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 origins: Optional[pulumi.Input[Sequence[pulumi.Input['OriginPoolOriginArgs']]]] = None):
        """
        The set of arguments for constructing a OriginPool resource.
        :param pulumi.Input[builtins.str] origin_pool_name: The source address pool name.
        :param pulumi.Input[builtins.int] site_id: The site ID.
        :param pulumi.Input[builtins.bool] enabled: Whether the source address pool is enabled:
        :param pulumi.Input[Sequence[pulumi.Input['OriginPoolOriginArgs']]] origins: The Source station information added to the source address pool. Multiple Source stations use arrays to transfer values. See `origins` below.
        """
        pulumi.set(__self__, "origin_pool_name", origin_pool_name)
        pulumi.set(__self__, "site_id", site_id)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if origins is not None:
            pulumi.set(__self__, "origins", origins)

    @property
    @pulumi.getter(name="originPoolName")
    def origin_pool_name(self) -> pulumi.Input[builtins.str]:
        """
        The source address pool name.
        """
        return pulumi.get(self, "origin_pool_name")

    @origin_pool_name.setter
    def origin_pool_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "origin_pool_name", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Input[builtins.int]:
        """
        The site ID.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether the source address pool is enabled:
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter
    def origins(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['OriginPoolOriginArgs']]]]:
        """
        The Source station information added to the source address pool. Multiple Source stations use arrays to transfer values. See `origins` below.
        """
        return pulumi.get(self, "origins")

    @origins.setter
    def origins(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['OriginPoolOriginArgs']]]]):
        pulumi.set(self, "origins", value)


@pulumi.input_type
class _OriginPoolState:
    def __init__(__self__, *,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 origin_pool_id: Optional[pulumi.Input[builtins.int]] = None,
                 origin_pool_name: Optional[pulumi.Input[builtins.str]] = None,
                 origins: Optional[pulumi.Input[Sequence[pulumi.Input['OriginPoolOriginArgs']]]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering OriginPool resources.
        :param pulumi.Input[builtins.bool] enabled: Whether the source address pool is enabled:
        :param pulumi.Input[builtins.int] origin_pool_id: OriginPool Id
        :param pulumi.Input[builtins.str] origin_pool_name: The source address pool name.
        :param pulumi.Input[Sequence[pulumi.Input['OriginPoolOriginArgs']]] origins: The Source station information added to the source address pool. Multiple Source stations use arrays to transfer values. See `origins` below.
        :param pulumi.Input[builtins.int] site_id: The site ID.
        """
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if origin_pool_id is not None:
            pulumi.set(__self__, "origin_pool_id", origin_pool_id)
        if origin_pool_name is not None:
            pulumi.set(__self__, "origin_pool_name", origin_pool_name)
        if origins is not None:
            pulumi.set(__self__, "origins", origins)
        if site_id is not None:
            pulumi.set(__self__, "site_id", site_id)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether the source address pool is enabled:
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="originPoolId")
    def origin_pool_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        OriginPool Id
        """
        return pulumi.get(self, "origin_pool_id")

    @origin_pool_id.setter
    def origin_pool_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "origin_pool_id", value)

    @property
    @pulumi.getter(name="originPoolName")
    def origin_pool_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The source address pool name.
        """
        return pulumi.get(self, "origin_pool_name")

    @origin_pool_name.setter
    def origin_pool_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "origin_pool_name", value)

    @property
    @pulumi.getter
    def origins(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['OriginPoolOriginArgs']]]]:
        """
        The Source station information added to the source address pool. Multiple Source stations use arrays to transfer values. See `origins` below.
        """
        return pulumi.get(self, "origins")

    @origins.setter
    def origins(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['OriginPoolOriginArgs']]]]):
        pulumi.set(self, "origins", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The site ID.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_id", value)


@pulumi.type_token("alicloud:esa/originPool:OriginPool")
class OriginPool(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 origin_pool_name: Optional[pulumi.Input[builtins.str]] = None,
                 origins: Optional[pulumi.Input[Sequence[pulumi.Input[Union['OriginPoolOriginArgs', 'OriginPoolOriginArgsDict']]]]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        """
        Provides a ESA Origin Pool resource.

        For information about ESA Origin Pool and how to use it, see [What is Origin Pool](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateOriginPool).

        > **NOTE:** Available since v1.244.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan")
        default_integer = random.index.Integer("default",
            min=10000,
            max=99999)
        default_site = alicloud.esa.Site("default",
            site_name=f"gositecdn-{default_integer['result']}.cn",
            instance_id=default.sites[0].instance_id,
            coverage="overseas",
            access_type="NS")
        default_origin_pool = alicloud.esa.OriginPool("default",
            origins=[
                {
                    "type": "OSS",
                    "address": "example.oss-cn-beijing.aliyuncs.com",
                    "header": "{\\"Host\\":[\\"example.oss-cn-beijing.aliyuncs.com\\"]}",
                    "enabled": True,
                    "auth_conf": {
                        "secret_key": "<SecretKeyId>",
                        "auth_type": "private_cross_account",
                        "access_key": "<AccessKeyId>",
                    },
                    "weight": 50,
                    "name": "origin1",
                },
                {
                    "address": "example.s3.com",
                    "header": "{\\"Host\\": [\\"example1.com\\"]}",
                    "enabled": True,
                    "auth_conf": {
                        "version": "v2",
                        "region": "us-east-1",
                        "auth_type": "private",
                        "access_key": "<AccessKeyId>",
                        "secret_key": "<SecretKeyId>",
                    },
                    "weight": 50,
                    "name": "origin2",
                    "type": "S3",
                },
                {
                    "type": "S3",
                    "address": "example1111.s3.com",
                    "header": "{\\"Host\\":[\\"example1111.com\\"]}",
                    "enabled": True,
                    "auth_conf": {
                        "secret_key": "<SecretKeyId>",
                        "version": "v2",
                        "region": "us-east-1",
                        "auth_type": "private",
                        "access_key": "<AccessKeyId>",
                    },
                    "weight": 30,
                    "name": "origin3",
                },
            ],
            site_id=default_site.id,
            origin_pool_name="exampleoriginpool",
            enabled=True)
        ```

        ## Import

        ESA Origin Pool can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/originPool:OriginPool example <site_id>:<origin_pool_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] enabled: Whether the source address pool is enabled:
        :param pulumi.Input[builtins.str] origin_pool_name: The source address pool name.
        :param pulumi.Input[Sequence[pulumi.Input[Union['OriginPoolOriginArgs', 'OriginPoolOriginArgsDict']]]] origins: The Source station information added to the source address pool. Multiple Source stations use arrays to transfer values. See `origins` below.
        :param pulumi.Input[builtins.int] site_id: The site ID.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: OriginPoolArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ESA Origin Pool resource.

        For information about ESA Origin Pool and how to use it, see [What is Origin Pool](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateOriginPool).

        > **NOTE:** Available since v1.244.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan")
        default_integer = random.index.Integer("default",
            min=10000,
            max=99999)
        default_site = alicloud.esa.Site("default",
            site_name=f"gositecdn-{default_integer['result']}.cn",
            instance_id=default.sites[0].instance_id,
            coverage="overseas",
            access_type="NS")
        default_origin_pool = alicloud.esa.OriginPool("default",
            origins=[
                {
                    "type": "OSS",
                    "address": "example.oss-cn-beijing.aliyuncs.com",
                    "header": "{\\"Host\\":[\\"example.oss-cn-beijing.aliyuncs.com\\"]}",
                    "enabled": True,
                    "auth_conf": {
                        "secret_key": "<SecretKeyId>",
                        "auth_type": "private_cross_account",
                        "access_key": "<AccessKeyId>",
                    },
                    "weight": 50,
                    "name": "origin1",
                },
                {
                    "address": "example.s3.com",
                    "header": "{\\"Host\\": [\\"example1.com\\"]}",
                    "enabled": True,
                    "auth_conf": {
                        "version": "v2",
                        "region": "us-east-1",
                        "auth_type": "private",
                        "access_key": "<AccessKeyId>",
                        "secret_key": "<SecretKeyId>",
                    },
                    "weight": 50,
                    "name": "origin2",
                    "type": "S3",
                },
                {
                    "type": "S3",
                    "address": "example1111.s3.com",
                    "header": "{\\"Host\\":[\\"example1111.com\\"]}",
                    "enabled": True,
                    "auth_conf": {
                        "secret_key": "<SecretKeyId>",
                        "version": "v2",
                        "region": "us-east-1",
                        "auth_type": "private",
                        "access_key": "<AccessKeyId>",
                    },
                    "weight": 30,
                    "name": "origin3",
                },
            ],
            site_id=default_site.id,
            origin_pool_name="exampleoriginpool",
            enabled=True)
        ```

        ## Import

        ESA Origin Pool can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/originPool:OriginPool example <site_id>:<origin_pool_id>
        ```

        :param str resource_name: The name of the resource.
        :param OriginPoolArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OriginPoolArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 origin_pool_name: Optional[pulumi.Input[builtins.str]] = None,
                 origins: Optional[pulumi.Input[Sequence[pulumi.Input[Union['OriginPoolOriginArgs', 'OriginPoolOriginArgsDict']]]]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OriginPoolArgs.__new__(OriginPoolArgs)

            __props__.__dict__["enabled"] = enabled
            if origin_pool_name is None and not opts.urn:
                raise TypeError("Missing required property 'origin_pool_name'")
            __props__.__dict__["origin_pool_name"] = origin_pool_name
            __props__.__dict__["origins"] = origins
            if site_id is None and not opts.urn:
                raise TypeError("Missing required property 'site_id'")
            __props__.__dict__["site_id"] = site_id
            __props__.__dict__["origin_pool_id"] = None
        super(OriginPool, __self__).__init__(
            'alicloud:esa/originPool:OriginPool',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            enabled: Optional[pulumi.Input[builtins.bool]] = None,
            origin_pool_id: Optional[pulumi.Input[builtins.int]] = None,
            origin_pool_name: Optional[pulumi.Input[builtins.str]] = None,
            origins: Optional[pulumi.Input[Sequence[pulumi.Input[Union['OriginPoolOriginArgs', 'OriginPoolOriginArgsDict']]]]] = None,
            site_id: Optional[pulumi.Input[builtins.int]] = None) -> 'OriginPool':
        """
        Get an existing OriginPool resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] enabled: Whether the source address pool is enabled:
        :param pulumi.Input[builtins.int] origin_pool_id: OriginPool Id
        :param pulumi.Input[builtins.str] origin_pool_name: The source address pool name.
        :param pulumi.Input[Sequence[pulumi.Input[Union['OriginPoolOriginArgs', 'OriginPoolOriginArgsDict']]]] origins: The Source station information added to the source address pool. Multiple Source stations use arrays to transfer values. See `origins` below.
        :param pulumi.Input[builtins.int] site_id: The site ID.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OriginPoolState.__new__(_OriginPoolState)

        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["origin_pool_id"] = origin_pool_id
        __props__.__dict__["origin_pool_name"] = origin_pool_name
        __props__.__dict__["origins"] = origins
        __props__.__dict__["site_id"] = site_id
        return OriginPool(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Whether the source address pool is enabled:
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="originPoolId")
    def origin_pool_id(self) -> pulumi.Output[builtins.int]:
        """
        OriginPool Id
        """
        return pulumi.get(self, "origin_pool_id")

    @property
    @pulumi.getter(name="originPoolName")
    def origin_pool_name(self) -> pulumi.Output[builtins.str]:
        """
        The source address pool name.
        """
        return pulumi.get(self, "origin_pool_name")

    @property
    @pulumi.getter
    def origins(self) -> pulumi.Output[Optional[Sequence['outputs.OriginPoolOrigin']]]:
        """
        The Source station information added to the source address pool. Multiple Source stations use arrays to transfer values. See `origins` below.
        """
        return pulumi.get(self, "origins")

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Output[builtins.int]:
        """
        The site ID.
        """
        return pulumi.get(self, "site_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DirectoryArgs', 'Directory']

@pulumi.input_type
class DirectoryArgs:
    def __init__(__self__, *,
                 directory_global_access_status: Optional[pulumi.Input[builtins.str]] = None,
                 directory_name: Optional[pulumi.Input[builtins.str]] = None,
                 login_preference: Optional[pulumi.Input['DirectoryLoginPreferenceArgs']] = None,
                 mfa_authentication_setting_info: Optional[pulumi.Input['DirectoryMfaAuthenticationSettingInfoArgs']] = None,
                 mfa_authentication_status: Optional[pulumi.Input[builtins.str]] = None,
                 password_policy: Optional[pulumi.Input['DirectoryPasswordPolicyArgs']] = None,
                 saml_identity_provider_configuration: Optional[pulumi.Input['DirectorySamlIdentityProviderConfigurationArgs']] = None,
                 saml_service_provider: Optional[pulumi.Input['DirectorySamlServiceProviderArgs']] = None,
                 scim_synchronization_status: Optional[pulumi.Input[builtins.str]] = None,
                 user_provisioning_configuration: Optional[pulumi.Input['DirectoryUserProvisioningConfigurationArgs']] = None):
        """
        The set of arguments for constructing a Directory resource.
        :param pulumi.Input[builtins.str] directory_global_access_status: Directory Global Acceleration activation status
        :param pulumi.Input[builtins.str] directory_name: DirectoryName
        :param pulumi.Input['DirectoryLoginPreferenceArgs'] login_preference: Login preferences See `login_preference` below.
        :param pulumi.Input['DirectoryMfaAuthenticationSettingInfoArgs'] mfa_authentication_setting_info: Global MFA verification configuration. See `mfa_authentication_setting_info` below.
        :param pulumi.Input[builtins.str] mfa_authentication_status: MFA Authentication Status
        :param pulumi.Input['DirectoryPasswordPolicyArgs'] password_policy: Password policy See `password_policy` below.
        :param pulumi.Input['DirectorySamlIdentityProviderConfigurationArgs'] saml_identity_provider_configuration: Identity Provider (IDP) See `saml_identity_provider_configuration` below.
        :param pulumi.Input['DirectorySamlServiceProviderArgs'] saml_service_provider: SP information. See `saml_service_provider` below.
        :param pulumi.Input[builtins.str] scim_synchronization_status: SCIM Synchronization Status
        :param pulumi.Input['DirectoryUserProvisioningConfigurationArgs'] user_provisioning_configuration: User Provisioning configuration See `user_provisioning_configuration` below.
        """
        if directory_global_access_status is not None:
            pulumi.set(__self__, "directory_global_access_status", directory_global_access_status)
        if directory_name is not None:
            pulumi.set(__self__, "directory_name", directory_name)
        if login_preference is not None:
            pulumi.set(__self__, "login_preference", login_preference)
        if mfa_authentication_setting_info is not None:
            pulumi.set(__self__, "mfa_authentication_setting_info", mfa_authentication_setting_info)
        if mfa_authentication_status is not None:
            pulumi.set(__self__, "mfa_authentication_status", mfa_authentication_status)
        if password_policy is not None:
            pulumi.set(__self__, "password_policy", password_policy)
        if saml_identity_provider_configuration is not None:
            pulumi.set(__self__, "saml_identity_provider_configuration", saml_identity_provider_configuration)
        if saml_service_provider is not None:
            pulumi.set(__self__, "saml_service_provider", saml_service_provider)
        if scim_synchronization_status is not None:
            pulumi.set(__self__, "scim_synchronization_status", scim_synchronization_status)
        if user_provisioning_configuration is not None:
            pulumi.set(__self__, "user_provisioning_configuration", user_provisioning_configuration)

    @property
    @pulumi.getter(name="directoryGlobalAccessStatus")
    def directory_global_access_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Directory Global Acceleration activation status
        """
        return pulumi.get(self, "directory_global_access_status")

    @directory_global_access_status.setter
    def directory_global_access_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "directory_global_access_status", value)

    @property
    @pulumi.getter(name="directoryName")
    def directory_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        DirectoryName
        """
        return pulumi.get(self, "directory_name")

    @directory_name.setter
    def directory_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "directory_name", value)

    @property
    @pulumi.getter(name="loginPreference")
    def login_preference(self) -> Optional[pulumi.Input['DirectoryLoginPreferenceArgs']]:
        """
        Login preferences See `login_preference` below.
        """
        return pulumi.get(self, "login_preference")

    @login_preference.setter
    def login_preference(self, value: Optional[pulumi.Input['DirectoryLoginPreferenceArgs']]):
        pulumi.set(self, "login_preference", value)

    @property
    @pulumi.getter(name="mfaAuthenticationSettingInfo")
    def mfa_authentication_setting_info(self) -> Optional[pulumi.Input['DirectoryMfaAuthenticationSettingInfoArgs']]:
        """
        Global MFA verification configuration. See `mfa_authentication_setting_info` below.
        """
        return pulumi.get(self, "mfa_authentication_setting_info")

    @mfa_authentication_setting_info.setter
    def mfa_authentication_setting_info(self, value: Optional[pulumi.Input['DirectoryMfaAuthenticationSettingInfoArgs']]):
        pulumi.set(self, "mfa_authentication_setting_info", value)

    @property
    @pulumi.getter(name="mfaAuthenticationStatus")
    def mfa_authentication_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        MFA Authentication Status
        """
        return pulumi.get(self, "mfa_authentication_status")

    @mfa_authentication_status.setter
    def mfa_authentication_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mfa_authentication_status", value)

    @property
    @pulumi.getter(name="passwordPolicy")
    def password_policy(self) -> Optional[pulumi.Input['DirectoryPasswordPolicyArgs']]:
        """
        Password policy See `password_policy` below.
        """
        return pulumi.get(self, "password_policy")

    @password_policy.setter
    def password_policy(self, value: Optional[pulumi.Input['DirectoryPasswordPolicyArgs']]):
        pulumi.set(self, "password_policy", value)

    @property
    @pulumi.getter(name="samlIdentityProviderConfiguration")
    def saml_identity_provider_configuration(self) -> Optional[pulumi.Input['DirectorySamlIdentityProviderConfigurationArgs']]:
        """
        Identity Provider (IDP) See `saml_identity_provider_configuration` below.
        """
        return pulumi.get(self, "saml_identity_provider_configuration")

    @saml_identity_provider_configuration.setter
    def saml_identity_provider_configuration(self, value: Optional[pulumi.Input['DirectorySamlIdentityProviderConfigurationArgs']]):
        pulumi.set(self, "saml_identity_provider_configuration", value)

    @property
    @pulumi.getter(name="samlServiceProvider")
    def saml_service_provider(self) -> Optional[pulumi.Input['DirectorySamlServiceProviderArgs']]:
        """
        SP information. See `saml_service_provider` below.
        """
        return pulumi.get(self, "saml_service_provider")

    @saml_service_provider.setter
    def saml_service_provider(self, value: Optional[pulumi.Input['DirectorySamlServiceProviderArgs']]):
        pulumi.set(self, "saml_service_provider", value)

    @property
    @pulumi.getter(name="scimSynchronizationStatus")
    def scim_synchronization_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        SCIM Synchronization Status
        """
        return pulumi.get(self, "scim_synchronization_status")

    @scim_synchronization_status.setter
    def scim_synchronization_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "scim_synchronization_status", value)

    @property
    @pulumi.getter(name="userProvisioningConfiguration")
    def user_provisioning_configuration(self) -> Optional[pulumi.Input['DirectoryUserProvisioningConfigurationArgs']]:
        """
        User Provisioning configuration See `user_provisioning_configuration` below.
        """
        return pulumi.get(self, "user_provisioning_configuration")

    @user_provisioning_configuration.setter
    def user_provisioning_configuration(self, value: Optional[pulumi.Input['DirectoryUserProvisioningConfigurationArgs']]):
        pulumi.set(self, "user_provisioning_configuration", value)


@pulumi.input_type
class _DirectoryState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 directory_global_access_status: Optional[pulumi.Input[builtins.str]] = None,
                 directory_name: Optional[pulumi.Input[builtins.str]] = None,
                 login_preference: Optional[pulumi.Input['DirectoryLoginPreferenceArgs']] = None,
                 mfa_authentication_setting_info: Optional[pulumi.Input['DirectoryMfaAuthenticationSettingInfoArgs']] = None,
                 mfa_authentication_status: Optional[pulumi.Input[builtins.str]] = None,
                 password_policy: Optional[pulumi.Input['DirectoryPasswordPolicyArgs']] = None,
                 saml_identity_provider_configuration: Optional[pulumi.Input['DirectorySamlIdentityProviderConfigurationArgs']] = None,
                 saml_service_provider: Optional[pulumi.Input['DirectorySamlServiceProviderArgs']] = None,
                 scim_synchronization_status: Optional[pulumi.Input[builtins.str]] = None,
                 user_provisioning_configuration: Optional[pulumi.Input['DirectoryUserProvisioningConfigurationArgs']] = None):
        """
        Input properties used for looking up and filtering Directory resources.
        :param pulumi.Input[builtins.str] create_time: CreateTime
        :param pulumi.Input[builtins.str] directory_global_access_status: Directory Global Acceleration activation status
        :param pulumi.Input[builtins.str] directory_name: DirectoryName
        :param pulumi.Input['DirectoryLoginPreferenceArgs'] login_preference: Login preferences See `login_preference` below.
        :param pulumi.Input['DirectoryMfaAuthenticationSettingInfoArgs'] mfa_authentication_setting_info: Global MFA verification configuration. See `mfa_authentication_setting_info` below.
        :param pulumi.Input[builtins.str] mfa_authentication_status: MFA Authentication Status
        :param pulumi.Input['DirectoryPasswordPolicyArgs'] password_policy: Password policy See `password_policy` below.
        :param pulumi.Input['DirectorySamlIdentityProviderConfigurationArgs'] saml_identity_provider_configuration: Identity Provider (IDP) See `saml_identity_provider_configuration` below.
        :param pulumi.Input['DirectorySamlServiceProviderArgs'] saml_service_provider: SP information. See `saml_service_provider` below.
        :param pulumi.Input[builtins.str] scim_synchronization_status: SCIM Synchronization Status
        :param pulumi.Input['DirectoryUserProvisioningConfigurationArgs'] user_provisioning_configuration: User Provisioning configuration See `user_provisioning_configuration` below.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if directory_global_access_status is not None:
            pulumi.set(__self__, "directory_global_access_status", directory_global_access_status)
        if directory_name is not None:
            pulumi.set(__self__, "directory_name", directory_name)
        if login_preference is not None:
            pulumi.set(__self__, "login_preference", login_preference)
        if mfa_authentication_setting_info is not None:
            pulumi.set(__self__, "mfa_authentication_setting_info", mfa_authentication_setting_info)
        if mfa_authentication_status is not None:
            pulumi.set(__self__, "mfa_authentication_status", mfa_authentication_status)
        if password_policy is not None:
            pulumi.set(__self__, "password_policy", password_policy)
        if saml_identity_provider_configuration is not None:
            pulumi.set(__self__, "saml_identity_provider_configuration", saml_identity_provider_configuration)
        if saml_service_provider is not None:
            pulumi.set(__self__, "saml_service_provider", saml_service_provider)
        if scim_synchronization_status is not None:
            pulumi.set(__self__, "scim_synchronization_status", scim_synchronization_status)
        if user_provisioning_configuration is not None:
            pulumi.set(__self__, "user_provisioning_configuration", user_provisioning_configuration)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        CreateTime
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="directoryGlobalAccessStatus")
    def directory_global_access_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Directory Global Acceleration activation status
        """
        return pulumi.get(self, "directory_global_access_status")

    @directory_global_access_status.setter
    def directory_global_access_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "directory_global_access_status", value)

    @property
    @pulumi.getter(name="directoryName")
    def directory_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        DirectoryName
        """
        return pulumi.get(self, "directory_name")

    @directory_name.setter
    def directory_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "directory_name", value)

    @property
    @pulumi.getter(name="loginPreference")
    def login_preference(self) -> Optional[pulumi.Input['DirectoryLoginPreferenceArgs']]:
        """
        Login preferences See `login_preference` below.
        """
        return pulumi.get(self, "login_preference")

    @login_preference.setter
    def login_preference(self, value: Optional[pulumi.Input['DirectoryLoginPreferenceArgs']]):
        pulumi.set(self, "login_preference", value)

    @property
    @pulumi.getter(name="mfaAuthenticationSettingInfo")
    def mfa_authentication_setting_info(self) -> Optional[pulumi.Input['DirectoryMfaAuthenticationSettingInfoArgs']]:
        """
        Global MFA verification configuration. See `mfa_authentication_setting_info` below.
        """
        return pulumi.get(self, "mfa_authentication_setting_info")

    @mfa_authentication_setting_info.setter
    def mfa_authentication_setting_info(self, value: Optional[pulumi.Input['DirectoryMfaAuthenticationSettingInfoArgs']]):
        pulumi.set(self, "mfa_authentication_setting_info", value)

    @property
    @pulumi.getter(name="mfaAuthenticationStatus")
    def mfa_authentication_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        MFA Authentication Status
        """
        return pulumi.get(self, "mfa_authentication_status")

    @mfa_authentication_status.setter
    def mfa_authentication_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mfa_authentication_status", value)

    @property
    @pulumi.getter(name="passwordPolicy")
    def password_policy(self) -> Optional[pulumi.Input['DirectoryPasswordPolicyArgs']]:
        """
        Password policy See `password_policy` below.
        """
        return pulumi.get(self, "password_policy")

    @password_policy.setter
    def password_policy(self, value: Optional[pulumi.Input['DirectoryPasswordPolicyArgs']]):
        pulumi.set(self, "password_policy", value)

    @property
    @pulumi.getter(name="samlIdentityProviderConfiguration")
    def saml_identity_provider_configuration(self) -> Optional[pulumi.Input['DirectorySamlIdentityProviderConfigurationArgs']]:
        """
        Identity Provider (IDP) See `saml_identity_provider_configuration` below.
        """
        return pulumi.get(self, "saml_identity_provider_configuration")

    @saml_identity_provider_configuration.setter
    def saml_identity_provider_configuration(self, value: Optional[pulumi.Input['DirectorySamlIdentityProviderConfigurationArgs']]):
        pulumi.set(self, "saml_identity_provider_configuration", value)

    @property
    @pulumi.getter(name="samlServiceProvider")
    def saml_service_provider(self) -> Optional[pulumi.Input['DirectorySamlServiceProviderArgs']]:
        """
        SP information. See `saml_service_provider` below.
        """
        return pulumi.get(self, "saml_service_provider")

    @saml_service_provider.setter
    def saml_service_provider(self, value: Optional[pulumi.Input['DirectorySamlServiceProviderArgs']]):
        pulumi.set(self, "saml_service_provider", value)

    @property
    @pulumi.getter(name="scimSynchronizationStatus")
    def scim_synchronization_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        SCIM Synchronization Status
        """
        return pulumi.get(self, "scim_synchronization_status")

    @scim_synchronization_status.setter
    def scim_synchronization_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "scim_synchronization_status", value)

    @property
    @pulumi.getter(name="userProvisioningConfiguration")
    def user_provisioning_configuration(self) -> Optional[pulumi.Input['DirectoryUserProvisioningConfigurationArgs']]:
        """
        User Provisioning configuration See `user_provisioning_configuration` below.
        """
        return pulumi.get(self, "user_provisioning_configuration")

    @user_provisioning_configuration.setter
    def user_provisioning_configuration(self, value: Optional[pulumi.Input['DirectoryUserProvisioningConfigurationArgs']]):
        pulumi.set(self, "user_provisioning_configuration", value)


@pulumi.type_token("alicloud:cloudsso/directory:Directory")
class Directory(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 directory_global_access_status: Optional[pulumi.Input[builtins.str]] = None,
                 directory_name: Optional[pulumi.Input[builtins.str]] = None,
                 login_preference: Optional[pulumi.Input[Union['DirectoryLoginPreferenceArgs', 'DirectoryLoginPreferenceArgsDict']]] = None,
                 mfa_authentication_setting_info: Optional[pulumi.Input[Union['DirectoryMfaAuthenticationSettingInfoArgs', 'DirectoryMfaAuthenticationSettingInfoArgsDict']]] = None,
                 mfa_authentication_status: Optional[pulumi.Input[builtins.str]] = None,
                 password_policy: Optional[pulumi.Input[Union['DirectoryPasswordPolicyArgs', 'DirectoryPasswordPolicyArgsDict']]] = None,
                 saml_identity_provider_configuration: Optional[pulumi.Input[Union['DirectorySamlIdentityProviderConfigurationArgs', 'DirectorySamlIdentityProviderConfigurationArgsDict']]] = None,
                 saml_service_provider: Optional[pulumi.Input[Union['DirectorySamlServiceProviderArgs', 'DirectorySamlServiceProviderArgsDict']]] = None,
                 scim_synchronization_status: Optional[pulumi.Input[builtins.str]] = None,
                 user_provisioning_configuration: Optional[pulumi.Input[Union['DirectoryUserProvisioningConfigurationArgs', 'DirectoryUserProvisioningConfigurationArgsDict']]] = None,
                 __props__=None):
        """
        Provides a Cloud SSO Directory resource.

        For information about Cloud SSO Directory and how to use it, see [What is Directory](https://www.alibabacloud.com/help/en/cloudsso/latest/api-cloudsso-2021-05-15-createdirectory).

        > **NOTE:** Available since v1.135.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        default = alicloud.cloudsso.Directory("default", directory_name=name)
        ```

        ## Import

        Cloud SSO Directory can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cloudsso/directory:Directory example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] directory_global_access_status: Directory Global Acceleration activation status
        :param pulumi.Input[builtins.str] directory_name: DirectoryName
        :param pulumi.Input[Union['DirectoryLoginPreferenceArgs', 'DirectoryLoginPreferenceArgsDict']] login_preference: Login preferences See `login_preference` below.
        :param pulumi.Input[Union['DirectoryMfaAuthenticationSettingInfoArgs', 'DirectoryMfaAuthenticationSettingInfoArgsDict']] mfa_authentication_setting_info: Global MFA verification configuration. See `mfa_authentication_setting_info` below.
        :param pulumi.Input[builtins.str] mfa_authentication_status: MFA Authentication Status
        :param pulumi.Input[Union['DirectoryPasswordPolicyArgs', 'DirectoryPasswordPolicyArgsDict']] password_policy: Password policy See `password_policy` below.
        :param pulumi.Input[Union['DirectorySamlIdentityProviderConfigurationArgs', 'DirectorySamlIdentityProviderConfigurationArgsDict']] saml_identity_provider_configuration: Identity Provider (IDP) See `saml_identity_provider_configuration` below.
        :param pulumi.Input[Union['DirectorySamlServiceProviderArgs', 'DirectorySamlServiceProviderArgsDict']] saml_service_provider: SP information. See `saml_service_provider` below.
        :param pulumi.Input[builtins.str] scim_synchronization_status: SCIM Synchronization Status
        :param pulumi.Input[Union['DirectoryUserProvisioningConfigurationArgs', 'DirectoryUserProvisioningConfigurationArgsDict']] user_provisioning_configuration: User Provisioning configuration See `user_provisioning_configuration` below.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[DirectoryArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Cloud SSO Directory resource.

        For information about Cloud SSO Directory and how to use it, see [What is Directory](https://www.alibabacloud.com/help/en/cloudsso/latest/api-cloudsso-2021-05-15-createdirectory).

        > **NOTE:** Available since v1.135.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        default = alicloud.cloudsso.Directory("default", directory_name=name)
        ```

        ## Import

        Cloud SSO Directory can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cloudsso/directory:Directory example <id>
        ```

        :param str resource_name: The name of the resource.
        :param DirectoryArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DirectoryArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 directory_global_access_status: Optional[pulumi.Input[builtins.str]] = None,
                 directory_name: Optional[pulumi.Input[builtins.str]] = None,
                 login_preference: Optional[pulumi.Input[Union['DirectoryLoginPreferenceArgs', 'DirectoryLoginPreferenceArgsDict']]] = None,
                 mfa_authentication_setting_info: Optional[pulumi.Input[Union['DirectoryMfaAuthenticationSettingInfoArgs', 'DirectoryMfaAuthenticationSettingInfoArgsDict']]] = None,
                 mfa_authentication_status: Optional[pulumi.Input[builtins.str]] = None,
                 password_policy: Optional[pulumi.Input[Union['DirectoryPasswordPolicyArgs', 'DirectoryPasswordPolicyArgsDict']]] = None,
                 saml_identity_provider_configuration: Optional[pulumi.Input[Union['DirectorySamlIdentityProviderConfigurationArgs', 'DirectorySamlIdentityProviderConfigurationArgsDict']]] = None,
                 saml_service_provider: Optional[pulumi.Input[Union['DirectorySamlServiceProviderArgs', 'DirectorySamlServiceProviderArgsDict']]] = None,
                 scim_synchronization_status: Optional[pulumi.Input[builtins.str]] = None,
                 user_provisioning_configuration: Optional[pulumi.Input[Union['DirectoryUserProvisioningConfigurationArgs', 'DirectoryUserProvisioningConfigurationArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DirectoryArgs.__new__(DirectoryArgs)

            __props__.__dict__["directory_global_access_status"] = directory_global_access_status
            __props__.__dict__["directory_name"] = directory_name
            __props__.__dict__["login_preference"] = login_preference
            __props__.__dict__["mfa_authentication_setting_info"] = mfa_authentication_setting_info
            __props__.__dict__["mfa_authentication_status"] = mfa_authentication_status
            __props__.__dict__["password_policy"] = password_policy
            __props__.__dict__["saml_identity_provider_configuration"] = saml_identity_provider_configuration
            __props__.__dict__["saml_service_provider"] = saml_service_provider
            __props__.__dict__["scim_synchronization_status"] = scim_synchronization_status
            __props__.__dict__["user_provisioning_configuration"] = user_provisioning_configuration
            __props__.__dict__["create_time"] = None
        super(Directory, __self__).__init__(
            'alicloud:cloudsso/directory:Directory',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            directory_global_access_status: Optional[pulumi.Input[builtins.str]] = None,
            directory_name: Optional[pulumi.Input[builtins.str]] = None,
            login_preference: Optional[pulumi.Input[Union['DirectoryLoginPreferenceArgs', 'DirectoryLoginPreferenceArgsDict']]] = None,
            mfa_authentication_setting_info: Optional[pulumi.Input[Union['DirectoryMfaAuthenticationSettingInfoArgs', 'DirectoryMfaAuthenticationSettingInfoArgsDict']]] = None,
            mfa_authentication_status: Optional[pulumi.Input[builtins.str]] = None,
            password_policy: Optional[pulumi.Input[Union['DirectoryPasswordPolicyArgs', 'DirectoryPasswordPolicyArgsDict']]] = None,
            saml_identity_provider_configuration: Optional[pulumi.Input[Union['DirectorySamlIdentityProviderConfigurationArgs', 'DirectorySamlIdentityProviderConfigurationArgsDict']]] = None,
            saml_service_provider: Optional[pulumi.Input[Union['DirectorySamlServiceProviderArgs', 'DirectorySamlServiceProviderArgsDict']]] = None,
            scim_synchronization_status: Optional[pulumi.Input[builtins.str]] = None,
            user_provisioning_configuration: Optional[pulumi.Input[Union['DirectoryUserProvisioningConfigurationArgs', 'DirectoryUserProvisioningConfigurationArgsDict']]] = None) -> 'Directory':
        """
        Get an existing Directory resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] create_time: CreateTime
        :param pulumi.Input[builtins.str] directory_global_access_status: Directory Global Acceleration activation status
        :param pulumi.Input[builtins.str] directory_name: DirectoryName
        :param pulumi.Input[Union['DirectoryLoginPreferenceArgs', 'DirectoryLoginPreferenceArgsDict']] login_preference: Login preferences See `login_preference` below.
        :param pulumi.Input[Union['DirectoryMfaAuthenticationSettingInfoArgs', 'DirectoryMfaAuthenticationSettingInfoArgsDict']] mfa_authentication_setting_info: Global MFA verification configuration. See `mfa_authentication_setting_info` below.
        :param pulumi.Input[builtins.str] mfa_authentication_status: MFA Authentication Status
        :param pulumi.Input[Union['DirectoryPasswordPolicyArgs', 'DirectoryPasswordPolicyArgsDict']] password_policy: Password policy See `password_policy` below.
        :param pulumi.Input[Union['DirectorySamlIdentityProviderConfigurationArgs', 'DirectorySamlIdentityProviderConfigurationArgsDict']] saml_identity_provider_configuration: Identity Provider (IDP) See `saml_identity_provider_configuration` below.
        :param pulumi.Input[Union['DirectorySamlServiceProviderArgs', 'DirectorySamlServiceProviderArgsDict']] saml_service_provider: SP information. See `saml_service_provider` below.
        :param pulumi.Input[builtins.str] scim_synchronization_status: SCIM Synchronization Status
        :param pulumi.Input[Union['DirectoryUserProvisioningConfigurationArgs', 'DirectoryUserProvisioningConfigurationArgsDict']] user_provisioning_configuration: User Provisioning configuration See `user_provisioning_configuration` below.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DirectoryState.__new__(_DirectoryState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["directory_global_access_status"] = directory_global_access_status
        __props__.__dict__["directory_name"] = directory_name
        __props__.__dict__["login_preference"] = login_preference
        __props__.__dict__["mfa_authentication_setting_info"] = mfa_authentication_setting_info
        __props__.__dict__["mfa_authentication_status"] = mfa_authentication_status
        __props__.__dict__["password_policy"] = password_policy
        __props__.__dict__["saml_identity_provider_configuration"] = saml_identity_provider_configuration
        __props__.__dict__["saml_service_provider"] = saml_service_provider
        __props__.__dict__["scim_synchronization_status"] = scim_synchronization_status
        __props__.__dict__["user_provisioning_configuration"] = user_provisioning_configuration
        return Directory(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        CreateTime
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="directoryGlobalAccessStatus")
    def directory_global_access_status(self) -> pulumi.Output[builtins.str]:
        """
        Directory Global Acceleration activation status
        """
        return pulumi.get(self, "directory_global_access_status")

    @property
    @pulumi.getter(name="directoryName")
    def directory_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        DirectoryName
        """
        return pulumi.get(self, "directory_name")

    @property
    @pulumi.getter(name="loginPreference")
    def login_preference(self) -> pulumi.Output['outputs.DirectoryLoginPreference']:
        """
        Login preferences See `login_preference` below.
        """
        return pulumi.get(self, "login_preference")

    @property
    @pulumi.getter(name="mfaAuthenticationSettingInfo")
    def mfa_authentication_setting_info(self) -> pulumi.Output['outputs.DirectoryMfaAuthenticationSettingInfo']:
        """
        Global MFA verification configuration. See `mfa_authentication_setting_info` below.
        """
        return pulumi.get(self, "mfa_authentication_setting_info")

    @property
    @pulumi.getter(name="mfaAuthenticationStatus")
    def mfa_authentication_status(self) -> pulumi.Output[builtins.str]:
        """
        MFA Authentication Status
        """
        return pulumi.get(self, "mfa_authentication_status")

    @property
    @pulumi.getter(name="passwordPolicy")
    def password_policy(self) -> pulumi.Output['outputs.DirectoryPasswordPolicy']:
        """
        Password policy See `password_policy` below.
        """
        return pulumi.get(self, "password_policy")

    @property
    @pulumi.getter(name="samlIdentityProviderConfiguration")
    def saml_identity_provider_configuration(self) -> pulumi.Output['outputs.DirectorySamlIdentityProviderConfiguration']:
        """
        Identity Provider (IDP) See `saml_identity_provider_configuration` below.
        """
        return pulumi.get(self, "saml_identity_provider_configuration")

    @property
    @pulumi.getter(name="samlServiceProvider")
    def saml_service_provider(self) -> pulumi.Output['outputs.DirectorySamlServiceProvider']:
        """
        SP information. See `saml_service_provider` below.
        """
        return pulumi.get(self, "saml_service_provider")

    @property
    @pulumi.getter(name="scimSynchronizationStatus")
    def scim_synchronization_status(self) -> pulumi.Output[builtins.str]:
        """
        SCIM Synchronization Status
        """
        return pulumi.get(self, "scim_synchronization_status")

    @property
    @pulumi.getter(name="userProvisioningConfiguration")
    def user_provisioning_configuration(self) -> pulumi.Output['outputs.DirectoryUserProvisioningConfiguration']:
        """
        User Provisioning configuration See `user_provisioning_configuration` below.
        """
        return pulumi.get(self, "user_provisioning_configuration")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['VPCRouteEntryArgs', 'VPCRouteEntry']

@pulumi.input_type
class VPCRouteEntryArgs:
    def __init__(__self__, *,
                 destination_cidr_block: pulumi.Input[builtins.str],
                 route_table_id: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 next_hops: Optional[pulumi.Input[Sequence[pulumi.Input['VPCRouteEntryNextHopArgs']]]] = None,
                 nexthop_id: Optional[pulumi.Input[builtins.str]] = None,
                 nexthop_type: Optional[pulumi.Input[builtins.str]] = None,
                 route_entry_name: Optional[pulumi.Input[builtins.str]] = None,
                 route_publish_targets: Optional[pulumi.Input[Sequence[pulumi.Input['VPCRouteEntryRoutePublishTargetArgs']]]] = None):
        """
        The set of arguments for constructing a VPCRouteEntry resource.
        :param pulumi.Input[builtins.str] destination_cidr_block: The destination network segment of the routing entry.
        :param pulumi.Input[builtins.str] route_table_id: Routing table ID
        :param pulumi.Input[builtins.str] description: Description of the route entry.
        :param pulumi.Input[Sequence[pulumi.Input['VPCRouteEntryNextHopArgs']]] next_hops: Next jump See `next_hops` below.
        :param pulumi.Input[builtins.str] nexthop_id: The ID of the next hop instance of the custom route entry.
        :param pulumi.Input[builtins.str] nexthop_type: The type of the next hop of the custom route entry. Valid values:
               - `Instance` (default): The ECS Instance.
               - `HaVip`: a highly available virtual IP address.
               - `RouterInterface`: indicates the router interface.
               - **Network interface**: ENI.
               - `VpnGateway`: the VPN gateway.
               - `IPv6Gateway`:IPv6 gateway.
               - `NatGateway`:NAT gateway.
               - `Attachment`: The forwarding router.
               - `VpcPeer`:VPC peer connection.
               - `Ipv4Gateway`:IPv4 Gateway.
               - `GatewayEndpoint`: the gateway endpoint.
               - `Ecr`: Leased line gateway.
               - `GatewayLoadBalancerEndpoint`: The Gateway-based load balancing endpoint.
        :param pulumi.Input[builtins.str] route_entry_name: The name of the route entry.
        :param pulumi.Input[Sequence[pulumi.Input['VPCRouteEntryRoutePublishTargetArgs']]] route_publish_targets: Route publish status and publish target type See `route_publish_targets` below.
        """
        pulumi.set(__self__, "destination_cidr_block", destination_cidr_block)
        pulumi.set(__self__, "route_table_id", route_table_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if next_hops is not None:
            pulumi.set(__self__, "next_hops", next_hops)
        if nexthop_id is not None:
            pulumi.set(__self__, "nexthop_id", nexthop_id)
        if nexthop_type is not None:
            pulumi.set(__self__, "nexthop_type", nexthop_type)
        if route_entry_name is not None:
            pulumi.set(__self__, "route_entry_name", route_entry_name)
        if route_publish_targets is not None:
            pulumi.set(__self__, "route_publish_targets", route_publish_targets)

    @property
    @pulumi.getter(name="destinationCidrBlock")
    def destination_cidr_block(self) -> pulumi.Input[builtins.str]:
        """
        The destination network segment of the routing entry.
        """
        return pulumi.get(self, "destination_cidr_block")

    @destination_cidr_block.setter
    def destination_cidr_block(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "destination_cidr_block", value)

    @property
    @pulumi.getter(name="routeTableId")
    def route_table_id(self) -> pulumi.Input[builtins.str]:
        """
        Routing table ID
        """
        return pulumi.get(self, "route_table_id")

    @route_table_id.setter
    def route_table_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "route_table_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description of the route entry.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="nextHops")
    def next_hops(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VPCRouteEntryNextHopArgs']]]]:
        """
        Next jump See `next_hops` below.
        """
        return pulumi.get(self, "next_hops")

    @next_hops.setter
    def next_hops(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VPCRouteEntryNextHopArgs']]]]):
        pulumi.set(self, "next_hops", value)

    @property
    @pulumi.getter(name="nexthopId")
    def nexthop_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the next hop instance of the custom route entry.
        """
        return pulumi.get(self, "nexthop_id")

    @nexthop_id.setter
    def nexthop_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nexthop_id", value)

    @property
    @pulumi.getter(name="nexthopType")
    def nexthop_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of the next hop of the custom route entry. Valid values:
        - `Instance` (default): The ECS Instance.
        - `HaVip`: a highly available virtual IP address.
        - `RouterInterface`: indicates the router interface.
        - **Network interface**: ENI.
        - `VpnGateway`: the VPN gateway.
        - `IPv6Gateway`:IPv6 gateway.
        - `NatGateway`:NAT gateway.
        - `Attachment`: The forwarding router.
        - `VpcPeer`:VPC peer connection.
        - `Ipv4Gateway`:IPv4 Gateway.
        - `GatewayEndpoint`: the gateway endpoint.
        - `Ecr`: Leased line gateway.
        - `GatewayLoadBalancerEndpoint`: The Gateway-based load balancing endpoint.
        """
        return pulumi.get(self, "nexthop_type")

    @nexthop_type.setter
    def nexthop_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nexthop_type", value)

    @property
    @pulumi.getter(name="routeEntryName")
    def route_entry_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the route entry.
        """
        return pulumi.get(self, "route_entry_name")

    @route_entry_name.setter
    def route_entry_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "route_entry_name", value)

    @property
    @pulumi.getter(name="routePublishTargets")
    def route_publish_targets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VPCRouteEntryRoutePublishTargetArgs']]]]:
        """
        Route publish status and publish target type See `route_publish_targets` below.
        """
        return pulumi.get(self, "route_publish_targets")

    @route_publish_targets.setter
    def route_publish_targets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VPCRouteEntryRoutePublishTargetArgs']]]]):
        pulumi.set(self, "route_publish_targets", value)


@pulumi.input_type
class _VPCRouteEntryState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 destination_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 next_hops: Optional[pulumi.Input[Sequence[pulumi.Input['VPCRouteEntryNextHopArgs']]]] = None,
                 nexthop_id: Optional[pulumi.Input[builtins.str]] = None,
                 nexthop_type: Optional[pulumi.Input[builtins.str]] = None,
                 route_entry_name: Optional[pulumi.Input[builtins.str]] = None,
                 route_publish_targets: Optional[pulumi.Input[Sequence[pulumi.Input['VPCRouteEntryRoutePublishTargetArgs']]]] = None,
                 route_table_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering VPCRouteEntry resources.
        :param pulumi.Input[builtins.str] description: Description of the route entry.
        :param pulumi.Input[builtins.str] destination_cidr_block: The destination network segment of the routing entry.
        :param pulumi.Input[Sequence[pulumi.Input['VPCRouteEntryNextHopArgs']]] next_hops: Next jump See `next_hops` below.
        :param pulumi.Input[builtins.str] nexthop_id: The ID of the next hop instance of the custom route entry.
        :param pulumi.Input[builtins.str] nexthop_type: The type of the next hop of the custom route entry. Valid values:
               - `Instance` (default): The ECS Instance.
               - `HaVip`: a highly available virtual IP address.
               - `RouterInterface`: indicates the router interface.
               - **Network interface**: ENI.
               - `VpnGateway`: the VPN gateway.
               - `IPv6Gateway`:IPv6 gateway.
               - `NatGateway`:NAT gateway.
               - `Attachment`: The forwarding router.
               - `VpcPeer`:VPC peer connection.
               - `Ipv4Gateway`:IPv4 Gateway.
               - `GatewayEndpoint`: the gateway endpoint.
               - `Ecr`: Leased line gateway.
               - `GatewayLoadBalancerEndpoint`: The Gateway-based load balancing endpoint.
        :param pulumi.Input[builtins.str] route_entry_name: The name of the route entry.
        :param pulumi.Input[Sequence[pulumi.Input['VPCRouteEntryRoutePublishTargetArgs']]] route_publish_targets: Route publish status and publish target type See `route_publish_targets` below.
        :param pulumi.Input[builtins.str] route_table_id: Routing table ID
        :param pulumi.Input[builtins.str] status: The status of the route entry.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if destination_cidr_block is not None:
            pulumi.set(__self__, "destination_cidr_block", destination_cidr_block)
        if next_hops is not None:
            pulumi.set(__self__, "next_hops", next_hops)
        if nexthop_id is not None:
            pulumi.set(__self__, "nexthop_id", nexthop_id)
        if nexthop_type is not None:
            pulumi.set(__self__, "nexthop_type", nexthop_type)
        if route_entry_name is not None:
            pulumi.set(__self__, "route_entry_name", route_entry_name)
        if route_publish_targets is not None:
            pulumi.set(__self__, "route_publish_targets", route_publish_targets)
        if route_table_id is not None:
            pulumi.set(__self__, "route_table_id", route_table_id)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description of the route entry.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="destinationCidrBlock")
    def destination_cidr_block(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The destination network segment of the routing entry.
        """
        return pulumi.get(self, "destination_cidr_block")

    @destination_cidr_block.setter
    def destination_cidr_block(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "destination_cidr_block", value)

    @property
    @pulumi.getter(name="nextHops")
    def next_hops(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VPCRouteEntryNextHopArgs']]]]:
        """
        Next jump See `next_hops` below.
        """
        return pulumi.get(self, "next_hops")

    @next_hops.setter
    def next_hops(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VPCRouteEntryNextHopArgs']]]]):
        pulumi.set(self, "next_hops", value)

    @property
    @pulumi.getter(name="nexthopId")
    def nexthop_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the next hop instance of the custom route entry.
        """
        return pulumi.get(self, "nexthop_id")

    @nexthop_id.setter
    def nexthop_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nexthop_id", value)

    @property
    @pulumi.getter(name="nexthopType")
    def nexthop_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of the next hop of the custom route entry. Valid values:
        - `Instance` (default): The ECS Instance.
        - `HaVip`: a highly available virtual IP address.
        - `RouterInterface`: indicates the router interface.
        - **Network interface**: ENI.
        - `VpnGateway`: the VPN gateway.
        - `IPv6Gateway`:IPv6 gateway.
        - `NatGateway`:NAT gateway.
        - `Attachment`: The forwarding router.
        - `VpcPeer`:VPC peer connection.
        - `Ipv4Gateway`:IPv4 Gateway.
        - `GatewayEndpoint`: the gateway endpoint.
        - `Ecr`: Leased line gateway.
        - `GatewayLoadBalancerEndpoint`: The Gateway-based load balancing endpoint.
        """
        return pulumi.get(self, "nexthop_type")

    @nexthop_type.setter
    def nexthop_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nexthop_type", value)

    @property
    @pulumi.getter(name="routeEntryName")
    def route_entry_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the route entry.
        """
        return pulumi.get(self, "route_entry_name")

    @route_entry_name.setter
    def route_entry_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "route_entry_name", value)

    @property
    @pulumi.getter(name="routePublishTargets")
    def route_publish_targets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VPCRouteEntryRoutePublishTargetArgs']]]]:
        """
        Route publish status and publish target type See `route_publish_targets` below.
        """
        return pulumi.get(self, "route_publish_targets")

    @route_publish_targets.setter
    def route_publish_targets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VPCRouteEntryRoutePublishTargetArgs']]]]):
        pulumi.set(self, "route_publish_targets", value)

    @property
    @pulumi.getter(name="routeTableId")
    def route_table_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Routing table ID
        """
        return pulumi.get(self, "route_table_id")

    @route_table_id.setter
    def route_table_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "route_table_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the route entry.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("alicloud:vpc/vPCRouteEntry:VPCRouteEntry")
class VPCRouteEntry(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 destination_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 next_hops: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VPCRouteEntryNextHopArgs', 'VPCRouteEntryNextHopArgsDict']]]]] = None,
                 nexthop_id: Optional[pulumi.Input[builtins.str]] = None,
                 nexthop_type: Optional[pulumi.Input[builtins.str]] = None,
                 route_entry_name: Optional[pulumi.Input[builtins.str]] = None,
                 route_publish_targets: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VPCRouteEntryRoutePublishTargetArgs', 'VPCRouteEntryRoutePublishTargetArgsDict']]]]] = None,
                 route_table_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a VPC Route Entry resource.

        There are route entries in the routing table, and the next hop is judged based on the route entries.

        For information about VPC Route Entry and how to use it, see [What is Route Entry](https://www.alibabacloud.com/help/en/vpc/developer-reference/api-vpc-2016-04-28-createrouteentry).

        > **NOTE:** Available since v1.245.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.get_zones(available_disk_category="cloud_efficiency",
            available_resource_creation="VSwitch")
        default_get_images = alicloud.ecs.get_images(most_recent=True,
            owners="system")
        default_get_instance_types = alicloud.ecs.get_instance_types(availability_zone=default.zones[0].id,
            image_id=default_get_images.images[0].id)
        default_network = alicloud.vpc.Network("default",
            vpc_name=name,
            cidr_block="192.168.0.0/16")
        default_switch = alicloud.vpc.Switch("default",
            vswitch_name=name,
            vpc_id=default_network.id,
            cidr_block="192.168.192.0/24",
            zone_id=default.zones[0].id)
        default_security_group = alicloud.ecs.SecurityGroup("default",
            name=name,
            vpc_id=default_network.id)
        default_instance = alicloud.ecs.Instance("default",
            image_id=default_get_images.images[0].id,
            instance_type=default_get_instance_types.instance_types[0].id,
            security_groups=[__item.id for __item in [default_security_group]],
            internet_charge_type="PayByTraffic",
            internet_max_bandwidth_out=10,
            availability_zone=default_get_instance_types.instance_types[0].availability_zones[0],
            instance_charge_type="PostPaid",
            system_disk_category="cloud_efficiency",
            vswitch_id=default_switch.id,
            instance_name=name)
        foo = alicloud.vpc.RouteEntry("foo",
            route_table_id=default_network.route_table_id,
            destination_cidrblock="172.11.1.1/32",
            nexthop_type="Instance",
            nexthop_id=default_instance.id)
        ```

        ## Import

        VPC Route Entry can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:vpc/vPCRouteEntry:VPCRouteEntry example <route_table_id>:<destination_cidr_block>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: Description of the route entry.
        :param pulumi.Input[builtins.str] destination_cidr_block: The destination network segment of the routing entry.
        :param pulumi.Input[Sequence[pulumi.Input[Union['VPCRouteEntryNextHopArgs', 'VPCRouteEntryNextHopArgsDict']]]] next_hops: Next jump See `next_hops` below.
        :param pulumi.Input[builtins.str] nexthop_id: The ID of the next hop instance of the custom route entry.
        :param pulumi.Input[builtins.str] nexthop_type: The type of the next hop of the custom route entry. Valid values:
               - `Instance` (default): The ECS Instance.
               - `HaVip`: a highly available virtual IP address.
               - `RouterInterface`: indicates the router interface.
               - **Network interface**: ENI.
               - `VpnGateway`: the VPN gateway.
               - `IPv6Gateway`:IPv6 gateway.
               - `NatGateway`:NAT gateway.
               - `Attachment`: The forwarding router.
               - `VpcPeer`:VPC peer connection.
               - `Ipv4Gateway`:IPv4 Gateway.
               - `GatewayEndpoint`: the gateway endpoint.
               - `Ecr`: Leased line gateway.
               - `GatewayLoadBalancerEndpoint`: The Gateway-based load balancing endpoint.
        :param pulumi.Input[builtins.str] route_entry_name: The name of the route entry.
        :param pulumi.Input[Sequence[pulumi.Input[Union['VPCRouteEntryRoutePublishTargetArgs', 'VPCRouteEntryRoutePublishTargetArgsDict']]]] route_publish_targets: Route publish status and publish target type See `route_publish_targets` below.
        :param pulumi.Input[builtins.str] route_table_id: Routing table ID
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VPCRouteEntryArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a VPC Route Entry resource.

        There are route entries in the routing table, and the next hop is judged based on the route entries.

        For information about VPC Route Entry and how to use it, see [What is Route Entry](https://www.alibabacloud.com/help/en/vpc/developer-reference/api-vpc-2016-04-28-createrouteentry).

        > **NOTE:** Available since v1.245.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.get_zones(available_disk_category="cloud_efficiency",
            available_resource_creation="VSwitch")
        default_get_images = alicloud.ecs.get_images(most_recent=True,
            owners="system")
        default_get_instance_types = alicloud.ecs.get_instance_types(availability_zone=default.zones[0].id,
            image_id=default_get_images.images[0].id)
        default_network = alicloud.vpc.Network("default",
            vpc_name=name,
            cidr_block="192.168.0.0/16")
        default_switch = alicloud.vpc.Switch("default",
            vswitch_name=name,
            vpc_id=default_network.id,
            cidr_block="192.168.192.0/24",
            zone_id=default.zones[0].id)
        default_security_group = alicloud.ecs.SecurityGroup("default",
            name=name,
            vpc_id=default_network.id)
        default_instance = alicloud.ecs.Instance("default",
            image_id=default_get_images.images[0].id,
            instance_type=default_get_instance_types.instance_types[0].id,
            security_groups=[__item.id for __item in [default_security_group]],
            internet_charge_type="PayByTraffic",
            internet_max_bandwidth_out=10,
            availability_zone=default_get_instance_types.instance_types[0].availability_zones[0],
            instance_charge_type="PostPaid",
            system_disk_category="cloud_efficiency",
            vswitch_id=default_switch.id,
            instance_name=name)
        foo = alicloud.vpc.RouteEntry("foo",
            route_table_id=default_network.route_table_id,
            destination_cidrblock="172.11.1.1/32",
            nexthop_type="Instance",
            nexthop_id=default_instance.id)
        ```

        ## Import

        VPC Route Entry can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:vpc/vPCRouteEntry:VPCRouteEntry example <route_table_id>:<destination_cidr_block>
        ```

        :param str resource_name: The name of the resource.
        :param VPCRouteEntryArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VPCRouteEntryArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 destination_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 next_hops: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VPCRouteEntryNextHopArgs', 'VPCRouteEntryNextHopArgsDict']]]]] = None,
                 nexthop_id: Optional[pulumi.Input[builtins.str]] = None,
                 nexthop_type: Optional[pulumi.Input[builtins.str]] = None,
                 route_entry_name: Optional[pulumi.Input[builtins.str]] = None,
                 route_publish_targets: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VPCRouteEntryRoutePublishTargetArgs', 'VPCRouteEntryRoutePublishTargetArgsDict']]]]] = None,
                 route_table_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VPCRouteEntryArgs.__new__(VPCRouteEntryArgs)

            __props__.__dict__["description"] = description
            if destination_cidr_block is None and not opts.urn:
                raise TypeError("Missing required property 'destination_cidr_block'")
            __props__.__dict__["destination_cidr_block"] = destination_cidr_block
            __props__.__dict__["next_hops"] = next_hops
            __props__.__dict__["nexthop_id"] = nexthop_id
            __props__.__dict__["nexthop_type"] = nexthop_type
            __props__.__dict__["route_entry_name"] = route_entry_name
            __props__.__dict__["route_publish_targets"] = route_publish_targets
            if route_table_id is None and not opts.urn:
                raise TypeError("Missing required property 'route_table_id'")
            __props__.__dict__["route_table_id"] = route_table_id
            __props__.__dict__["status"] = None
        super(VPCRouteEntry, __self__).__init__(
            'alicloud:vpc/vPCRouteEntry:VPCRouteEntry',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            destination_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
            next_hops: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VPCRouteEntryNextHopArgs', 'VPCRouteEntryNextHopArgsDict']]]]] = None,
            nexthop_id: Optional[pulumi.Input[builtins.str]] = None,
            nexthop_type: Optional[pulumi.Input[builtins.str]] = None,
            route_entry_name: Optional[pulumi.Input[builtins.str]] = None,
            route_publish_targets: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VPCRouteEntryRoutePublishTargetArgs', 'VPCRouteEntryRoutePublishTargetArgsDict']]]]] = None,
            route_table_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None) -> 'VPCRouteEntry':
        """
        Get an existing VPCRouteEntry resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: Description of the route entry.
        :param pulumi.Input[builtins.str] destination_cidr_block: The destination network segment of the routing entry.
        :param pulumi.Input[Sequence[pulumi.Input[Union['VPCRouteEntryNextHopArgs', 'VPCRouteEntryNextHopArgsDict']]]] next_hops: Next jump See `next_hops` below.
        :param pulumi.Input[builtins.str] nexthop_id: The ID of the next hop instance of the custom route entry.
        :param pulumi.Input[builtins.str] nexthop_type: The type of the next hop of the custom route entry. Valid values:
               - `Instance` (default): The ECS Instance.
               - `HaVip`: a highly available virtual IP address.
               - `RouterInterface`: indicates the router interface.
               - **Network interface**: ENI.
               - `VpnGateway`: the VPN gateway.
               - `IPv6Gateway`:IPv6 gateway.
               - `NatGateway`:NAT gateway.
               - `Attachment`: The forwarding router.
               - `VpcPeer`:VPC peer connection.
               - `Ipv4Gateway`:IPv4 Gateway.
               - `GatewayEndpoint`: the gateway endpoint.
               - `Ecr`: Leased line gateway.
               - `GatewayLoadBalancerEndpoint`: The Gateway-based load balancing endpoint.
        :param pulumi.Input[builtins.str] route_entry_name: The name of the route entry.
        :param pulumi.Input[Sequence[pulumi.Input[Union['VPCRouteEntryRoutePublishTargetArgs', 'VPCRouteEntryRoutePublishTargetArgsDict']]]] route_publish_targets: Route publish status and publish target type See `route_publish_targets` below.
        :param pulumi.Input[builtins.str] route_table_id: Routing table ID
        :param pulumi.Input[builtins.str] status: The status of the route entry.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VPCRouteEntryState.__new__(_VPCRouteEntryState)

        __props__.__dict__["description"] = description
        __props__.__dict__["destination_cidr_block"] = destination_cidr_block
        __props__.__dict__["next_hops"] = next_hops
        __props__.__dict__["nexthop_id"] = nexthop_id
        __props__.__dict__["nexthop_type"] = nexthop_type
        __props__.__dict__["route_entry_name"] = route_entry_name
        __props__.__dict__["route_publish_targets"] = route_publish_targets
        __props__.__dict__["route_table_id"] = route_table_id
        __props__.__dict__["status"] = status
        return VPCRouteEntry(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Description of the route entry.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="destinationCidrBlock")
    def destination_cidr_block(self) -> pulumi.Output[builtins.str]:
        """
        The destination network segment of the routing entry.
        """
        return pulumi.get(self, "destination_cidr_block")

    @property
    @pulumi.getter(name="nextHops")
    def next_hops(self) -> pulumi.Output[Sequence['outputs.VPCRouteEntryNextHop']]:
        """
        Next jump See `next_hops` below.
        """
        return pulumi.get(self, "next_hops")

    @property
    @pulumi.getter(name="nexthopId")
    def nexthop_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the next hop instance of the custom route entry.
        """
        return pulumi.get(self, "nexthop_id")

    @property
    @pulumi.getter(name="nexthopType")
    def nexthop_type(self) -> pulumi.Output[builtins.str]:
        """
        The type of the next hop of the custom route entry. Valid values:
        - `Instance` (default): The ECS Instance.
        - `HaVip`: a highly available virtual IP address.
        - `RouterInterface`: indicates the router interface.
        - **Network interface**: ENI.
        - `VpnGateway`: the VPN gateway.
        - `IPv6Gateway`:IPv6 gateway.
        - `NatGateway`:NAT gateway.
        - `Attachment`: The forwarding router.
        - `VpcPeer`:VPC peer connection.
        - `Ipv4Gateway`:IPv4 Gateway.
        - `GatewayEndpoint`: the gateway endpoint.
        - `Ecr`: Leased line gateway.
        - `GatewayLoadBalancerEndpoint`: The Gateway-based load balancing endpoint.
        """
        return pulumi.get(self, "nexthop_type")

    @property
    @pulumi.getter(name="routeEntryName")
    def route_entry_name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the route entry.
        """
        return pulumi.get(self, "route_entry_name")

    @property
    @pulumi.getter(name="routePublishTargets")
    def route_publish_targets(self) -> pulumi.Output[Optional[Sequence['outputs.VPCRouteEntryRoutePublishTarget']]]:
        """
        Route publish status and publish target type See `route_publish_targets` below.
        """
        return pulumi.get(self, "route_publish_targets")

    @property
    @pulumi.getter(name="routeTableId")
    def route_table_id(self) -> pulumi.Output[builtins.str]:
        """
        Routing table ID
        """
        return pulumi.get(self, "route_table_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        The status of the route entry.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['WorkspaceModelArgs', 'WorkspaceModel']

@pulumi.input_type
class WorkspaceModelArgs:
    def __init__(__self__, *,
                 model_name: pulumi.Input[builtins.str],
                 accessibility: Optional[pulumi.Input[builtins.str]] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 extra_info: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceModelLabelArgs']]]] = None,
                 model_description: Optional[pulumi.Input[builtins.str]] = None,
                 model_doc: Optional[pulumi.Input[builtins.str]] = None,
                 model_type: Optional[pulumi.Input[builtins.str]] = None,
                 order_number: Optional[pulumi.Input[builtins.int]] = None,
                 origin: Optional[pulumi.Input[builtins.str]] = None,
                 task: Optional[pulumi.Input[builtins.str]] = None,
                 workspace_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a WorkspaceModel resource.
        :param pulumi.Input[builtins.str] model_name: The name of the model. The name must be 1 to 127 characters in length.
        :param pulumi.Input[builtins.str] accessibility: The visibility of the model in the workspace. Default value: `PRIVATE`. Valid values:
               - `PRIVATE`: In this workspace, it is only visible to you and the administrator.
               - `PUBLIC`: In this workspace, it is visible to everyone.
        :param pulumi.Input[builtins.str] domain: The domain of the model. Describe the domain in which the model solves the problem. For example: nlp (natural language processing), cv (computer vision), etc.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] extra_info: Other information about the model.
        :param pulumi.Input[Sequence[pulumi.Input['WorkspaceModelLabelArgs']]] labels: A list of tags. See `labels` below.
        :param pulumi.Input[builtins.str] model_description: The model description, used to distinguish different models.
        :param pulumi.Input[builtins.str] model_doc: The documentation of the model.
        :param pulumi.Input[builtins.str] model_type: The model type. Example: Checkpoint or LoRA.
        :param pulumi.Input[builtins.int] order_number: The sequence number of the model. Can be used for custom sorting.
        :param pulumi.Input[builtins.str] origin: The source of the model. The community or organization to which the source model belongs, such as ModelScope or HuggingFace.
        :param pulumi.Input[builtins.str] task: The task of the model. Describes the specific problem that the model solves. Example: text-classification.
        :param pulumi.Input[builtins.str] workspace_id: The ID of the workspace.
        """
        pulumi.set(__self__, "model_name", model_name)
        if accessibility is not None:
            pulumi.set(__self__, "accessibility", accessibility)
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if extra_info is not None:
            pulumi.set(__self__, "extra_info", extra_info)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if model_description is not None:
            pulumi.set(__self__, "model_description", model_description)
        if model_doc is not None:
            pulumi.set(__self__, "model_doc", model_doc)
        if model_type is not None:
            pulumi.set(__self__, "model_type", model_type)
        if order_number is not None:
            pulumi.set(__self__, "order_number", order_number)
        if origin is not None:
            pulumi.set(__self__, "origin", origin)
        if task is not None:
            pulumi.set(__self__, "task", task)
        if workspace_id is not None:
            pulumi.set(__self__, "workspace_id", workspace_id)

    @property
    @pulumi.getter(name="modelName")
    def model_name(self) -> pulumi.Input[builtins.str]:
        """
        The name of the model. The name must be 1 to 127 characters in length.
        """
        return pulumi.get(self, "model_name")

    @model_name.setter
    def model_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "model_name", value)

    @property
    @pulumi.getter
    def accessibility(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The visibility of the model in the workspace. Default value: `PRIVATE`. Valid values:
        - `PRIVATE`: In this workspace, it is only visible to you and the administrator.
        - `PUBLIC`: In this workspace, it is visible to everyone.
        """
        return pulumi.get(self, "accessibility")

    @accessibility.setter
    def accessibility(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "accessibility", value)

    @property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The domain of the model. Describe the domain in which the model solves the problem. For example: nlp (natural language processing), cv (computer vision), etc.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="extraInfo")
    def extra_info(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Other information about the model.
        """
        return pulumi.get(self, "extra_info")

    @extra_info.setter
    def extra_info(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "extra_info", value)

    @property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceModelLabelArgs']]]]:
        """
        A list of tags. See `labels` below.
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceModelLabelArgs']]]]):
        pulumi.set(self, "labels", value)

    @property
    @pulumi.getter(name="modelDescription")
    def model_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The model description, used to distinguish different models.
        """
        return pulumi.get(self, "model_description")

    @model_description.setter
    def model_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "model_description", value)

    @property
    @pulumi.getter(name="modelDoc")
    def model_doc(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The documentation of the model.
        """
        return pulumi.get(self, "model_doc")

    @model_doc.setter
    def model_doc(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "model_doc", value)

    @property
    @pulumi.getter(name="modelType")
    def model_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The model type. Example: Checkpoint or LoRA.
        """
        return pulumi.get(self, "model_type")

    @model_type.setter
    def model_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "model_type", value)

    @property
    @pulumi.getter(name="orderNumber")
    def order_number(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The sequence number of the model. Can be used for custom sorting.
        """
        return pulumi.get(self, "order_number")

    @order_number.setter
    def order_number(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "order_number", value)

    @property
    @pulumi.getter
    def origin(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The source of the model. The community or organization to which the source model belongs, such as ModelScope or HuggingFace.
        """
        return pulumi.get(self, "origin")

    @origin.setter
    def origin(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "origin", value)

    @property
    @pulumi.getter
    def task(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The task of the model. Describes the specific problem that the model solves. Example: text-classification.
        """
        return pulumi.get(self, "task")

    @task.setter
    def task(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "task", value)

    @property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the workspace.
        """
        return pulumi.get(self, "workspace_id")

    @workspace_id.setter
    def workspace_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "workspace_id", value)


@pulumi.input_type
class _WorkspaceModelState:
    def __init__(__self__, *,
                 accessibility: Optional[pulumi.Input[builtins.str]] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 extra_info: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceModelLabelArgs']]]] = None,
                 model_description: Optional[pulumi.Input[builtins.str]] = None,
                 model_doc: Optional[pulumi.Input[builtins.str]] = None,
                 model_name: Optional[pulumi.Input[builtins.str]] = None,
                 model_type: Optional[pulumi.Input[builtins.str]] = None,
                 order_number: Optional[pulumi.Input[builtins.int]] = None,
                 origin: Optional[pulumi.Input[builtins.str]] = None,
                 task: Optional[pulumi.Input[builtins.str]] = None,
                 workspace_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering WorkspaceModel resources.
        :param pulumi.Input[builtins.str] accessibility: The visibility of the model in the workspace. Default value: `PRIVATE`. Valid values:
               - `PRIVATE`: In this workspace, it is only visible to you and the administrator.
               - `PUBLIC`: In this workspace, it is visible to everyone.
        :param pulumi.Input[builtins.str] domain: The domain of the model. Describe the domain in which the model solves the problem. For example: nlp (natural language processing), cv (computer vision), etc.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] extra_info: Other information about the model.
        :param pulumi.Input[Sequence[pulumi.Input['WorkspaceModelLabelArgs']]] labels: A list of tags. See `labels` below.
        :param pulumi.Input[builtins.str] model_description: The model description, used to distinguish different models.
        :param pulumi.Input[builtins.str] model_doc: The documentation of the model.
        :param pulumi.Input[builtins.str] model_name: The name of the model. The name must be 1 to 127 characters in length.
        :param pulumi.Input[builtins.str] model_type: The model type. Example: Checkpoint or LoRA.
        :param pulumi.Input[builtins.int] order_number: The sequence number of the model. Can be used for custom sorting.
        :param pulumi.Input[builtins.str] origin: The source of the model. The community or organization to which the source model belongs, such as ModelScope or HuggingFace.
        :param pulumi.Input[builtins.str] task: The task of the model. Describes the specific problem that the model solves. Example: text-classification.
        :param pulumi.Input[builtins.str] workspace_id: The ID of the workspace.
        """
        if accessibility is not None:
            pulumi.set(__self__, "accessibility", accessibility)
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if extra_info is not None:
            pulumi.set(__self__, "extra_info", extra_info)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if model_description is not None:
            pulumi.set(__self__, "model_description", model_description)
        if model_doc is not None:
            pulumi.set(__self__, "model_doc", model_doc)
        if model_name is not None:
            pulumi.set(__self__, "model_name", model_name)
        if model_type is not None:
            pulumi.set(__self__, "model_type", model_type)
        if order_number is not None:
            pulumi.set(__self__, "order_number", order_number)
        if origin is not None:
            pulumi.set(__self__, "origin", origin)
        if task is not None:
            pulumi.set(__self__, "task", task)
        if workspace_id is not None:
            pulumi.set(__self__, "workspace_id", workspace_id)

    @property
    @pulumi.getter
    def accessibility(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The visibility of the model in the workspace. Default value: `PRIVATE`. Valid values:
        - `PRIVATE`: In this workspace, it is only visible to you and the administrator.
        - `PUBLIC`: In this workspace, it is visible to everyone.
        """
        return pulumi.get(self, "accessibility")

    @accessibility.setter
    def accessibility(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "accessibility", value)

    @property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The domain of the model. Describe the domain in which the model solves the problem. For example: nlp (natural language processing), cv (computer vision), etc.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="extraInfo")
    def extra_info(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Other information about the model.
        """
        return pulumi.get(self, "extra_info")

    @extra_info.setter
    def extra_info(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "extra_info", value)

    @property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceModelLabelArgs']]]]:
        """
        A list of tags. See `labels` below.
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceModelLabelArgs']]]]):
        pulumi.set(self, "labels", value)

    @property
    @pulumi.getter(name="modelDescription")
    def model_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The model description, used to distinguish different models.
        """
        return pulumi.get(self, "model_description")

    @model_description.setter
    def model_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "model_description", value)

    @property
    @pulumi.getter(name="modelDoc")
    def model_doc(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The documentation of the model.
        """
        return pulumi.get(self, "model_doc")

    @model_doc.setter
    def model_doc(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "model_doc", value)

    @property
    @pulumi.getter(name="modelName")
    def model_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the model. The name must be 1 to 127 characters in length.
        """
        return pulumi.get(self, "model_name")

    @model_name.setter
    def model_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "model_name", value)

    @property
    @pulumi.getter(name="modelType")
    def model_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The model type. Example: Checkpoint or LoRA.
        """
        return pulumi.get(self, "model_type")

    @model_type.setter
    def model_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "model_type", value)

    @property
    @pulumi.getter(name="orderNumber")
    def order_number(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The sequence number of the model. Can be used for custom sorting.
        """
        return pulumi.get(self, "order_number")

    @order_number.setter
    def order_number(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "order_number", value)

    @property
    @pulumi.getter
    def origin(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The source of the model. The community or organization to which the source model belongs, such as ModelScope or HuggingFace.
        """
        return pulumi.get(self, "origin")

    @origin.setter
    def origin(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "origin", value)

    @property
    @pulumi.getter
    def task(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The task of the model. Describes the specific problem that the model solves. Example: text-classification.
        """
        return pulumi.get(self, "task")

    @task.setter
    def task(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "task", value)

    @property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the workspace.
        """
        return pulumi.get(self, "workspace_id")

    @workspace_id.setter
    def workspace_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "workspace_id", value)


@pulumi.type_token("alicloud:pai/workspaceModel:WorkspaceModel")
class WorkspaceModel(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 accessibility: Optional[pulumi.Input[builtins.str]] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 extra_info: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceModelLabelArgs', 'WorkspaceModelLabelArgsDict']]]]] = None,
                 model_description: Optional[pulumi.Input[builtins.str]] = None,
                 model_doc: Optional[pulumi.Input[builtins.str]] = None,
                 model_name: Optional[pulumi.Input[builtins.str]] = None,
                 model_type: Optional[pulumi.Input[builtins.str]] = None,
                 order_number: Optional[pulumi.Input[builtins.int]] = None,
                 origin: Optional[pulumi.Input[builtins.str]] = None,
                 task: Optional[pulumi.Input[builtins.str]] = None,
                 workspace_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a PAI Workspace Model resource.

        For information about PAI Workspace Model and how to use it, see [What is Model](https://www.alibabacloud.com/help/en/pai/developer-reference/api-aiworkspace-2021-02-04-createmodel).

        > **NOTE:** Available since v1.249.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform_example"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        default_e_nu_c6u = alicloud.pai.WorkspaceWorkspace("defaultENuC6u",
            description="156",
            display_name=name,
            workspace_name=f"{name}_{default['result']}",
            env_types=["prod"])
        default_workspace_model = alicloud.pai.WorkspaceModel("default",
            origin="Civitai",
            task="text-to-image-synthesis",
            model_name=name,
            accessibility="PRIVATE",
            workspace_id=default_e_nu_c6u.id,
            model_type="Checkpoint",
            labels=[{
                "key": "base_model",
                "value": "SD 1.5",
            }],
            order_number=1,
            extra_info={
                "test": "15",
            },
            model_description="ModelDescription.",
            model_doc="https://eas-***.oss-cn-hangzhou.aliyuncs.com/s**.safetensors",
            domain="aigc")
        ```

        ## Import

        PAI Workspace Model can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:pai/workspaceModel:WorkspaceModel example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] accessibility: The visibility of the model in the workspace. Default value: `PRIVATE`. Valid values:
               - `PRIVATE`: In this workspace, it is only visible to you and the administrator.
               - `PUBLIC`: In this workspace, it is visible to everyone.
        :param pulumi.Input[builtins.str] domain: The domain of the model. Describe the domain in which the model solves the problem. For example: nlp (natural language processing), cv (computer vision), etc.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] extra_info: Other information about the model.
        :param pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceModelLabelArgs', 'WorkspaceModelLabelArgsDict']]]] labels: A list of tags. See `labels` below.
        :param pulumi.Input[builtins.str] model_description: The model description, used to distinguish different models.
        :param pulumi.Input[builtins.str] model_doc: The documentation of the model.
        :param pulumi.Input[builtins.str] model_name: The name of the model. The name must be 1 to 127 characters in length.
        :param pulumi.Input[builtins.str] model_type: The model type. Example: Checkpoint or LoRA.
        :param pulumi.Input[builtins.int] order_number: The sequence number of the model. Can be used for custom sorting.
        :param pulumi.Input[builtins.str] origin: The source of the model. The community or organization to which the source model belongs, such as ModelScope or HuggingFace.
        :param pulumi.Input[builtins.str] task: The task of the model. Describes the specific problem that the model solves. Example: text-classification.
        :param pulumi.Input[builtins.str] workspace_id: The ID of the workspace.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: WorkspaceModelArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a PAI Workspace Model resource.

        For information about PAI Workspace Model and how to use it, see [What is Model](https://www.alibabacloud.com/help/en/pai/developer-reference/api-aiworkspace-2021-02-04-createmodel).

        > **NOTE:** Available since v1.249.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform_example"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        default_e_nu_c6u = alicloud.pai.WorkspaceWorkspace("defaultENuC6u",
            description="156",
            display_name=name,
            workspace_name=f"{name}_{default['result']}",
            env_types=["prod"])
        default_workspace_model = alicloud.pai.WorkspaceModel("default",
            origin="Civitai",
            task="text-to-image-synthesis",
            model_name=name,
            accessibility="PRIVATE",
            workspace_id=default_e_nu_c6u.id,
            model_type="Checkpoint",
            labels=[{
                "key": "base_model",
                "value": "SD 1.5",
            }],
            order_number=1,
            extra_info={
                "test": "15",
            },
            model_description="ModelDescription.",
            model_doc="https://eas-***.oss-cn-hangzhou.aliyuncs.com/s**.safetensors",
            domain="aigc")
        ```

        ## Import

        PAI Workspace Model can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:pai/workspaceModel:WorkspaceModel example <id>
        ```

        :param str resource_name: The name of the resource.
        :param WorkspaceModelArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(WorkspaceModelArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 accessibility: Optional[pulumi.Input[builtins.str]] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 extra_info: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceModelLabelArgs', 'WorkspaceModelLabelArgsDict']]]]] = None,
                 model_description: Optional[pulumi.Input[builtins.str]] = None,
                 model_doc: Optional[pulumi.Input[builtins.str]] = None,
                 model_name: Optional[pulumi.Input[builtins.str]] = None,
                 model_type: Optional[pulumi.Input[builtins.str]] = None,
                 order_number: Optional[pulumi.Input[builtins.int]] = None,
                 origin: Optional[pulumi.Input[builtins.str]] = None,
                 task: Optional[pulumi.Input[builtins.str]] = None,
                 workspace_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = WorkspaceModelArgs.__new__(WorkspaceModelArgs)

            __props__.__dict__["accessibility"] = accessibility
            __props__.__dict__["domain"] = domain
            __props__.__dict__["extra_info"] = extra_info
            __props__.__dict__["labels"] = labels
            __props__.__dict__["model_description"] = model_description
            __props__.__dict__["model_doc"] = model_doc
            if model_name is None and not opts.urn:
                raise TypeError("Missing required property 'model_name'")
            __props__.__dict__["model_name"] = model_name
            __props__.__dict__["model_type"] = model_type
            __props__.__dict__["order_number"] = order_number
            __props__.__dict__["origin"] = origin
            __props__.__dict__["task"] = task
            __props__.__dict__["workspace_id"] = workspace_id
        super(WorkspaceModel, __self__).__init__(
            'alicloud:pai/workspaceModel:WorkspaceModel',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            accessibility: Optional[pulumi.Input[builtins.str]] = None,
            domain: Optional[pulumi.Input[builtins.str]] = None,
            extra_info: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
            labels: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceModelLabelArgs', 'WorkspaceModelLabelArgsDict']]]]] = None,
            model_description: Optional[pulumi.Input[builtins.str]] = None,
            model_doc: Optional[pulumi.Input[builtins.str]] = None,
            model_name: Optional[pulumi.Input[builtins.str]] = None,
            model_type: Optional[pulumi.Input[builtins.str]] = None,
            order_number: Optional[pulumi.Input[builtins.int]] = None,
            origin: Optional[pulumi.Input[builtins.str]] = None,
            task: Optional[pulumi.Input[builtins.str]] = None,
            workspace_id: Optional[pulumi.Input[builtins.str]] = None) -> 'WorkspaceModel':
        """
        Get an existing WorkspaceModel resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] accessibility: The visibility of the model in the workspace. Default value: `PRIVATE`. Valid values:
               - `PRIVATE`: In this workspace, it is only visible to you and the administrator.
               - `PUBLIC`: In this workspace, it is visible to everyone.
        :param pulumi.Input[builtins.str] domain: The domain of the model. Describe the domain in which the model solves the problem. For example: nlp (natural language processing), cv (computer vision), etc.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] extra_info: Other information about the model.
        :param pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceModelLabelArgs', 'WorkspaceModelLabelArgsDict']]]] labels: A list of tags. See `labels` below.
        :param pulumi.Input[builtins.str] model_description: The model description, used to distinguish different models.
        :param pulumi.Input[builtins.str] model_doc: The documentation of the model.
        :param pulumi.Input[builtins.str] model_name: The name of the model. The name must be 1 to 127 characters in length.
        :param pulumi.Input[builtins.str] model_type: The model type. Example: Checkpoint or LoRA.
        :param pulumi.Input[builtins.int] order_number: The sequence number of the model. Can be used for custom sorting.
        :param pulumi.Input[builtins.str] origin: The source of the model. The community or organization to which the source model belongs, such as ModelScope or HuggingFace.
        :param pulumi.Input[builtins.str] task: The task of the model. Describes the specific problem that the model solves. Example: text-classification.
        :param pulumi.Input[builtins.str] workspace_id: The ID of the workspace.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _WorkspaceModelState.__new__(_WorkspaceModelState)

        __props__.__dict__["accessibility"] = accessibility
        __props__.__dict__["domain"] = domain
        __props__.__dict__["extra_info"] = extra_info
        __props__.__dict__["labels"] = labels
        __props__.__dict__["model_description"] = model_description
        __props__.__dict__["model_doc"] = model_doc
        __props__.__dict__["model_name"] = model_name
        __props__.__dict__["model_type"] = model_type
        __props__.__dict__["order_number"] = order_number
        __props__.__dict__["origin"] = origin
        __props__.__dict__["task"] = task
        __props__.__dict__["workspace_id"] = workspace_id
        return WorkspaceModel(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def accessibility(self) -> pulumi.Output[builtins.str]:
        """
        The visibility of the model in the workspace. Default value: `PRIVATE`. Valid values:
        - `PRIVATE`: In this workspace, it is only visible to you and the administrator.
        - `PUBLIC`: In this workspace, it is visible to everyone.
        """
        return pulumi.get(self, "accessibility")

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The domain of the model. Describe the domain in which the model solves the problem. For example: nlp (natural language processing), cv (computer vision), etc.
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter(name="extraInfo")
    def extra_info(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        Other information about the model.
        """
        return pulumi.get(self, "extra_info")

    @property
    @pulumi.getter
    def labels(self) -> pulumi.Output[Optional[Sequence['outputs.WorkspaceModelLabel']]]:
        """
        A list of tags. See `labels` below.
        """
        return pulumi.get(self, "labels")

    @property
    @pulumi.getter(name="modelDescription")
    def model_description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The model description, used to distinguish different models.
        """
        return pulumi.get(self, "model_description")

    @property
    @pulumi.getter(name="modelDoc")
    def model_doc(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The documentation of the model.
        """
        return pulumi.get(self, "model_doc")

    @property
    @pulumi.getter(name="modelName")
    def model_name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the model. The name must be 1 to 127 characters in length.
        """
        return pulumi.get(self, "model_name")

    @property
    @pulumi.getter(name="modelType")
    def model_type(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The model type. Example: Checkpoint or LoRA.
        """
        return pulumi.get(self, "model_type")

    @property
    @pulumi.getter(name="orderNumber")
    def order_number(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        The sequence number of the model. Can be used for custom sorting.
        """
        return pulumi.get(self, "order_number")

    @property
    @pulumi.getter
    def origin(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The source of the model. The community or organization to which the source model belongs, such as ModelScope or HuggingFace.
        """
        return pulumi.get(self, "origin")

    @property
    @pulumi.getter
    def task(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The task of the model. Describes the specific problem that the model solves. Example: text-classification.
        """
        return pulumi.get(self, "task")

    @property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the workspace.
        """
        return pulumi.get(self, "workspace_id")

